EdgeGenerator
========================

- :func:`edge_generator <parquetdb.graph.edges.edge_generator>` - A decorator that validates the input arguments of a function and converts them into a dataframe.

.. autosummary::
   :toctree: _autosummary

   parquetdb.graph.edges.edge_generator
